clear all
close all
clc

getd = @(p)path(p,path);

getd('toolbox_signal/');
getd('toolbox_general/');
getd('toolbox_graph/');

%% Points on boundary
% A 2D shape is a connected compact planar domain.
% It is represented as a black and white image corresponding 
% to the indicator function of the set.
t_boundary = tic;

n = 5000;

name = './figure/gardahr';

% Rescaling data in [0,1] (grayscale)
M = rescale( load_image(name,n) );

% Threshold to be sure to have a binary image.
M = perform_blurring(M,3);
M = double(M>.5);

% Compute the boundaries of the shape.
bound0 = compute_shape_boundary(M);

% Re-sample the boundary
nbound = 5000;

nbound0 = size(bound0,2);
t = linspace(1,nbound0,nbound+1); t(end) = [];
bound(1,:) = interp1( bound0(1,:), t );
bound(2,:) = interp1( bound0(2,:), t );
bound = bound';
t_elapsed_boundary = toc(t_boundary);

% Display the boundary.
figure;

% Rotate the boundary to avoid axis('ij')
theta = 90 * pi/180;
T = [cos(theta) sin(-theta);
   sin(theta) cos(theta)];
b = [bound(:,1),bound(:,2)]*T;

% Correction to have positive coordinates
b(:,2) = b(:,2) - min(b(:,2));

figure
hh = plot(b(:,1), b(:,2),'.');
set(hh, 'LineWidth', .5);
%axis('ij');
axis square;
axis equal;
print -depsc -tiff -r300 ./figure/gardaboundary5000;
save('GardaLakeBoundary5000.mat','b');

% triangulation
[vertices,faces] = mesh2d(b);

save('GardaLakeVertices.mat','vertices');
save('GardaLakeFaces.mat','faces');

print -depsc -tiff -r300 ./figure/gardatriangulation;

% zoom
figure
hold on
hh = plot(b(:,1), b(:,2),'r*');
set(hh, 'Markers',5);
triplot(faces,vertices(:,1),vertices(:,2))
xlim([1660,1820])
ylim([580,720])
hold off
print -depsc -tiff -r300 ./figure/gardatriangulationzoom;